@@ -1,4 +1,4 @@
-# last modified 2 June 2005 by J. Fox
+# last modified 24 June 2007 by J. Fox
 
 print.sem <- function(x, ...) {
     n <- x$n
@@ -7,8 +7,10 @@ print.sem <- function(x, ...) {
     df <- n*(n + 1)/2 - t - n.fix*(n.fix + 1)/2
     cat("\n Model Chisquare = ", x$criterion * (x$N - (!x$raw)), 
         "  Df = ", df, "\n\n")
-    print(x$coeff)
-    cat("\n Iterations = ", x$iterations, "\n")
-    if (!is.null(x$aliased)) cat("\n Aliased parameters:", x$aliased, "\n")
+    if (!is.null(x$coef)){
+        print(x$coeff)
+        cat("\n Iterations = ", x$iterations, "\n")
+        if (!is.null(x$aliased)) cat("\n Aliased parameters:", x$aliased, "\n")
+        }
     invisible(x)
     }
